@@ -4,8 +4,19 @@
 mod sys;
 use sys::*;
 
-mod imports;
-use imports::*;
+use fltk::app;
+use fltk::enums::*;
+use fltk::group;
+use fltk::image::Image;
+use fltk::prelude::*;
+use fltk::utils::FlString;
+use fltk::widget::Widget;
+use fltk::window::Window;
+use std::{
+    ffi::{CStr, CString},
+    mem,
+    os::raw,
+};
 
 use fltk::widget::WidgetTrackerPtr;
 
@@ -29,4 +40,4 @@ impl Flow {
             Fl_Flow_rule(self.inner, w.as_widget_ptr() as _, inst.as_ptr());
         }
     }
-}
\ No newline at end of file
+}
